﻿using System;
using System.Windows;
using System.Windows.Media.Animation;
using System.Windows.Shapes;

namespace TestProject
{
    /// <summary>
    /// 메인 윈도우
    /// </summary>
    public partial class MainWindow : Window
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 스토리 보드
        /// </summary>
        private Storyboard storyboard;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainWindow()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainWindow()
        {
            InitializeComponent();

            this.storyboard = new Storyboard();

            DoubleAnimation doubleAnimation = new DoubleAnimation();

            doubleAnimation.From        = 1.0;
            doubleAnimation.To          = 0.0;
            doubleAnimation.Duration    = new Duration(TimeSpan.FromMilliseconds(5000));

            Storyboard.SetTargetName    (doubleAnimation, this.rectangle.Name);
            Storyboard.SetTargetProperty(doubleAnimation, new PropertyPath(Rectangle.OpacityProperty));

            this.storyboard.Children.Add(doubleAnimation);

            this.beginButton.Click       += beginButton_Click;
            this.pauseButton.Click       += pauseButton_Click;
            this.resumeButton.Click      += resumeButton_Click;
            this.skipToFillButton.Click  += skipToFillButton_Click;
            this.tripleSpeedButton.Click += tripleSpeedButton_Click;
            this.stopButton.Click        += stopButton_Click;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Begin 버튼 클릭시 처리하기 - beginButton_Click(sender, e)

        /// <summary>
        /// Begin 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void beginButton_Click(object sender, RoutedEventArgs e)
        {
            this.storyboard.Begin(this, true);
        }

        #endregion
        #region Pause 버튼 클릭시 처리하기 - pauseButton_Click(sender, e)

        /// <summary>
        /// Pause 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void pauseButton_Click(object sender, RoutedEventArgs e)
        {
            this.storyboard.Pause(this);
        }

        #endregion
        #region Resume 버튼 클릭시 처리하기 - resumeButton_Click(sender, e)

        /// <summary>
        /// Resume 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void resumeButton_Click(object sender, RoutedEventArgs e)
        {
            this.storyboard.Resume(this);
        }

        #endregion
        #region Skip to Fill 버튼 클릭시 처리하기 - skipToFillButton_Click(sender, e)

        /// <summary>
        /// Skip to Fill 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void skipToFillButton_Click(object sender, RoutedEventArgs e)
        {
            this.storyboard.SkipToFill(this);
        }

        #endregion
        #region Triple Speed 버튼 클릭시 처리하기 - tripleSpeedButton_Click(sender, e)

        /// <summary>
        /// Triple Speed 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void tripleSpeedButton_Click(object sender, RoutedEventArgs e)
        {
            this.storyboard.SetSpeedRatio(this, 3);
        }

        #endregion
        #region Stop 버튼 클릭시 처리하기 - stopButton_Click(sender, e)

        /// <summary>
        /// Stop 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void stopButton_Click(object sender, RoutedEventArgs e)
        {
            this.storyboard.Stop(this);
        }

        #endregion
    }
}